#!/usr/bin/perl

=head1 NAME

Aunic::DomainModification - The Aunic Domain Modification HTML form

=head1 SYNOPSIS

 my $a = new Aunic::DomainModification(debug => 0);

 my $hashref = $a->get_defaults_from_file($filename);

=head1 DESCRIPTION

Use this package when you want to automate making a change to the
Aunic details regarding a domain name. For example, if you wish
to change tech or admin contact, or postal address.

get_defaults_from_file() returns a reference to a hash with the
field names which will have to be submitted in a reply form, which
should be POSTed using HTTP to B<http://cgi.aunic.net/cgi-bin/domain.pl>.

=cut

package Aunic::DomainModification;

use HTML::TreeBuilder;


sub new {
	my $class = shift;
	my $self = { @_ };

	bless $self, $class;

	return $self;
}

sub get_defaults_from_file {
	my $self = shift;
	my $file = shift;

	if (exists $self->{tree}) {
		$self->{tree}->delete();
		undef $self->{tree};
	}

	$self->{tree} = new HTML::TreeBuilder();

	$self->{tree}->parse_file($file);

	$self->{data_hr} = { };

	$self->parse_1($self->{data_hr}, $self->{tree});

	return $self->{data_hr};
}

sub dump {
	my $self = shift;

	my $data_hr = $self->{data_hr};

	if (%$data_hr) {
		foreach my $k (sort (keys %$data_hr)) {
			printf "%s: %s\n", $k, $data_hr->{$k};
		}

		return 1;
	}

	return 0;
}

sub parse_1 {
	my $self = shift;
	my $data_hr = shift;
	my $e = shift;

	# Be more detailed on certain types of things ...

	# Otherwise
	if (!ref $e) {
		if ($self->{debug}) {
			print "String: $e.\n";
		}
		return;
	}

	my $tag = $e->tag();

	if ($tag eq 'form') {
		$self->parse_form($data_hr, $e);
		return;
	}

	if ($self->{debug}) {
		print "Tag: $tag\n";
	}

	my @list = $e->content_list();

	foreach (@list) {
		$self->parse_1($data_hr, $_);
	}
}

sub parse_form {
	my $self = shift;
	my $data_hr = shift;
	my $e = shift;

	# Be more detailed on certain types of things ...

	# Otherwise
	if (!ref $e) {
		if ($self->{debug}) {
			print "String: $e.\n";
		}
		return;
	}

	my $tag = $e->tag();

	if ($tag eq 'input') {
		# Grab the field name and its current value
		my $name = $e->{name};
		my $value = $e->{value};

		if ($self->{debug}) {
			print "Found input tag: $name, $value\n";
		}

		if ($name ne '') {
			$data_hr->{$name} = $value;
		}

		# I think this is right, input tags don't have any content
		return;
	}

	if ($tag eq 'select') {
		my $name = $e->{name};

		$self->parse_select($data_hr, $name, $e);
		return;
	}

	if ($self->{debug}) {
		print "Tag: $tag\n";
	}

	my @list = $e->content_list();

	foreach (@list) {
		$self->parse_form($data_hr, $_);
	}
}

# parse_select($data_hr, $name, $e) ...

sub parse_select {
	my $self = shift;
	my $data_hr = shift;
	my $name = shift;
	my $e = shift;

	if (!ref $e) {
		if ($self->{debug}) {
			print "Oh oh, I didn't expect this: $e\n";
		}
		return;
	}

	my $tag = $e->tag();

	if ($tag eq 'option') {
		if ($self->{debug}) {
			print "Option: ", ($e->content_list())[0], "\n";
		}
		if ($e->{selected}) {
			my $value;

			# VALUE= attribute overrides content
			if (exists $e->{value}) {
				$value = $e->{value};
			} else {
				$value = ($e->content_list())[0];
			}

			if ($self->{debug}) {
				print "Found it ... $value\n";
			}

			$data_hr->{$name} = $value;
		}

		# Don't recursively parse the content of an option
		return;
	}

	my @list = $e->content_list();

	foreach (@list) {
		$self->parse_select($data_hr, $name, $_);
	}
}

1;
